﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

/*
 * File Renaming Wizard copyright (c) 2014 Matthew Schlachter
 * See LICENSE.txt for distribution and modification restrictions
 * 
 * http://www.webmann.info/
 */
namespace FileRenamingWizard
{
    /// <summary>
    /// Renames the files, keeping track of how many are skipped
    /// and how many are renamed
    /// </summary>
    public class FileRenamingManager
    {
        /// <summary>
        /// An array of the filenames (including paths)
        /// </summary>
        public string[] files { get; set; }
        /// <summary>
        /// The total number of files renamed/skipped in the <value>files</value> array
        /// </summary>
        public int curIndex { get; set; }
        /// <summary>
        /// The number of files renamed
        /// </summary>
        public int numRenamed { get; set; }
        /// <summary>
        /// The number of files skipped
        /// </summary>
        public int numSkipped { get; set; }
        /// <summary>
        /// Whether there are any files left in the <value>files</value> array;
        /// same as checking curIndex &lt; numFiles
        /// </summary>
        public bool hasNext { get { return curIndex < files.Length; } }
        /// <summary>
        /// The number of files in the <value>files</value> array
        /// </summary>
        public int numFiles { get { return files.Length; } }

        /// <summary>
        /// Instantiates the FileRenamingManager
        /// </summary>
        /// <param name="files">The array of filenames (including paths)</param>
        public FileRenamingManager(string[] files)
        {
            this.files = files;
            curIndex = 0;
            numRenamed = 0;
            numSkipped = 0;
        }

        /// <summary>
        /// Rename the current file and move to the next
        /// </summary>
        /// <param name="newName">The new filename (excluding the path)</param>
        public void rename(string newName)
        {
            System.IO.File.Move(files[curIndex], files[curIndex].Substring(0, files[curIndex].LastIndexOf("\\") + 1) + newName + files[curIndex].Substring(files[curIndex].LastIndexOf(".")));
            numRenamed++;
            curIndex++;
        }

        /// <summary>
        /// Skip the current file and move to the next
        /// </summary>
        public void skip()
        {
            numSkipped++;
            curIndex++;
        }

        /// <summary>
        /// Get the current filename of the current file
        /// </summary>
        /// <returns>The current filename</returns>
        public string getOldFileName()
        {
            return files[curIndex].Substring(files[curIndex].LastIndexOf("\\") + 1);
        }

        /// <summary>
        /// Gets the creation date of the file in the proper format for the filename convention
        /// </summary>
        /// <returns>A string representing the creation date of the current file</returns>
        public string getDate()
        {
            try
            {
                return System.IO.File.GetCreationTime(files[curIndex]).ToString("yyyyMMMdd");
            }
            catch
            {
                return "Date";
            }
        }

        /// <summary>
        /// Guesses at the correct type in the Type combo box using regular expressions on the type description
        /// </summary>
        /// <returns>The index for the Type combo box</returns>
        public int getTypeIndex()
        {
            string[] types = new string[] { "ThisIsJustAPlaceholderForCustom", "Accommodation", "Administration", "Agenda", "Agreement", "Assessment", "Backgrounder", "Best Practice", "Briefing", "Briefing Minister ESDC", "Briefing Minister Labour", "Briefing Deputy Minister ESDC", "Briefing Deputy Minister Labour", "Briefing Deputy Head Service Canada", "Briefing Assistant Deputy Minister", "Briefing – SOS", "Brochure", "Budget", "Business Case", "Business Continuity Plan", "Business Need", "Business Requirement", "Channel", "Communication", "Contract", "Correspondence", "Data and Statistics", "Directive", "Enquiry", "Event", "Financial", "Foreign Benefit", "Form", "Framework", "Graphical Material", "Guideline and Procedure", "Human Resources", "Information", "Information Kit", "Inquiry", "Invoice", "Itinerary", "Legal", "List", "Log", "Manual", "Medium Term Planning", "Media Advisory", "Media Line", "Meeting", "Memorandum", "Memorandum Of Understanding", "Minutes", "Newsletter", "News Release", "Outline", "Plan", "Policy", "Policy Reference Material", "Presentation|(pptx?$)", "Procedure", "Proposal", "Publication", "Question Period Card or Note", "Questions and Answers", "Record Of Decision", "Reference", "Release Note", "Report", "Scenario Note", "Schedule", "Scope", "Security", "Speech", "Speaking Notes", "Signature", "Statement Of Merit", "Standard", "Submission", "Survey", "Systems", "Template", "Terms Of Reference", "Test Script", "Training", "Transcode", "User Need", "User Requirement", "Web Update", "Work Description", "Work Plan", "World Wide Web" };

            for (int i = 0; i < types.Length; i++)
                if (System.Text.RegularExpressions.Regex.IsMatch(getOldFileName(), types[i], System.Text.RegularExpressions.RegexOptions.IgnoreCase))
                    return i;
            return -1;
        }
    }
}
